aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-iax2.c
diff options
context:
space:
mode:
authorDario Lombardo <lomato@gmail.com>2014-06-18 12:18:58 +0200
committerAnders Broman <a.broman58@gmail.com>2014-06-18 14:22:02 +0000
commit7fea55a0541bcc5059f767970b6f6291f81d7b9c (patch)
treefec52a9da08768f3035529202400164f24f470d9 /epan/dissectors/packet-iax2.c
parent021e7afc9fcba09094d0e2143cc434a34e3b09dc (diff)
Fixup: ep_address_to_str -> address_to_str
Change-Id: Id49ba07e32a71357b50b32de7cecfd80e412d508 Reviewed-on: https://code.wireshark.org/review/2379 Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'epan/dissectors/packet-iax2.c')
-rw-r--r--epan/dissectors/packet-iax2.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-iax2.c b/epan/dissectors/packet-iax2.c
index 7ab22eeb08..7fd57d4679 100644
--- a/epan/dissectors/packet-iax2.c
+++ b/epan/dissectors/packet-iax2.c
@@ -605,12 +605,12 @@ static gchar *key_to_str( const iax_circuit_key *key )
}
strp = str[i];
/* why doesn't ep_address_to_str take a const pointer?
cast the warnings into oblivion. */
/* XXX - is this a case for wmem_packet_scope()? */
g_snprintf(strp, 80, "{%s:%i,%i}",
- ep_address_to_str((address *)&key->addr),
+ address_to_str(wmem_packet_scope(), (address *)&key->addr),
key->port,
key->callno);
return strp;
@@ -932,8 +932,8 @@ static iax_call_data *iax_lookup_call( packet_info *pinfo,
#ifdef DEBUG_HASHING
g_debug("++ iax_lookup_circuit_details: Looking up circuit for frame %u, "
"from {%s:%u:%u} to {%s:%u:%u}", pinfo->fd->num,
- ep_address_to_str(&pinfo->src), pinfo->srcport, scallno,
- ep_address_to_str(&pinfo->dst), pinfo->destport, dcallno);
+ address_to_str(wmem_packet_scope(), &pinfo->src), pinfo->srcport, scallno,
+ address_to_str(wmem_packet_scope(), &pinfo->dst), pinfo->destport, dcallno);
#endif
@@ -605,12 +605,12 @@ static gchar *key_to_str( const iax_circuit_key *key )
}
strp = str[i];
- /* why doesn't ep_address_to_str take a const pointer?
+ /* why doesn't address_to_str take a const pointer?
cast the warnings into oblivion. */
/* XXX - is this a case for wmem_packet_scope()? */